==> jc-1.4.0.tar.gz: polyglot/util/NestedMap__241.c <==
// class polyglot.util.NestedMap$1

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 3222d3e1e6ee5a41 java_util_Map__24Entry
// @dep_class 8c5d73b7858cb7f9 polyglot_util_NestedMap
// @dep_class 783f7398f16c5125 polyglot_util_NestedMap__241
// @dep_class dd63687c349023fb polyglot_util_Predicate

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_HashMap
// @dep_header java_util_Map__24Entry
// @dep_header polyglot_util_NestedMap
// @dep_header polyglot_util_NestedMap__241
// @dep_header polyglot_util_Predicate

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/HashMap.h"
#include "java/util/Map__24Entry.h"
#include "polyglot/util/NestedMap.h"
#include "polyglot/util/NestedMap__241.h"
#include "polyglot/util/Predicate.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final polyglot.util.NestedMap this$0
static _jc_field _jc_polyglot_util_NestedMap__241$field_info$this__240 = {
	.name=		"this$0",
	.signature=	"Lpolyglot/util/NestedMap;",
	.class=		&_jc_polyglot_util_NestedMap__241$type,
	.type=		&_jc_polyglot_util_NestedMap$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_NestedMap__241$object, refs[-1].polyglot_util_NestedMap__241.this__240),
};

// Fields
static _jc_field *const _jc_polyglot_util_NestedMap__241$fields[] = {
	&_jc_polyglot_util_NestedMap__241$field_info$this__240
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(polyglot.util.NestedMap)
//

static _jc_linenum _jc_polyglot_util_NestedMap__241$linenum_table$_init$e86507e3abc60b21[];

static const unsigned char _jc_polyglot_util_NestedMap__241$param_ptypes$_init$e86507e3abc60b21[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_util_NestedMap__241$param_types$_init$e86507e3abc60b21[] = {
	&_jc_polyglot_util_NestedMap$type
};

_jc_method _jc_polyglot_util_NestedMap__241$method_info$_init$e86507e3abc60b21 = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/NestedMap;)V",
	.class=			&_jc_polyglot_util_NestedMap__241$type,
	.param_types=		&_jc_polyglot_util_NestedMap__241$param_types$_init$e86507e3abc60b21,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_util_NestedMap__241$param_ptypes$_init$e86507e3abc60b21,
	.signature_hash=	_JC_JLONG(0xe86507e3abc60b21),
	.access_flags=		0,
	.function=		&_jc_polyglot_util_NestedMap__241$method$_init$e86507e3abc60b21,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_NestedMap__241$linenum_table$_init$e86507e3abc60b21
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_NestedMap__241, _init$e86507e3abc60b21);

void
_jc_polyglot_util_NestedMap__241$method$_init$e86507e3abc60b21(_jc_env *const env, _jc_polyglot_util_NestedMap__241$object *this, _jc_polyglot_util_NestedMap$object *param0)
{
	struct _jc_polyglot_util_NestedMap__241$object *r0;
	struct _jc_polyglot_util_NestedMap$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(159);				// 0
	_JC_REF_FIELD(env, r0, polyglot_util_NestedMap__241, this__240) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean isTrue(java.lang.Object)
//

static _jc_linenum _jc_polyglot_util_NestedMap__241$linenum_table$isTrue$91ea4ebb04f439fb[];

static const unsigned char _jc_polyglot_util_NestedMap__241$param_ptypes$isTrue$91ea4ebb04f439fb[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_polyglot_util_NestedMap__241$param_types$isTrue$91ea4ebb04f439fb[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb = {
	.name=			"isTrue",
	.signature=		"(Ljava/lang/Object;)Z",
	.class=			&_jc_polyglot_util_NestedMap__241$type,
	.param_types=		&_jc_polyglot_util_NestedMap__241$param_types$isTrue$91ea4ebb04f439fb,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_polyglot_util_NestedMap__241$param_ptypes$isTrue$91ea4ebb04f439fb,
	.signature_hash=	_JC_JLONG(0x91ea4ebb04f439fb),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_NestedMap__241$vtable, polyglot_util_NestedMap__241.isTrue$91ea4ebb04f439fb) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_polyglot_util_NestedMap__241$linenum_table$isTrue$91ea4ebb04f439fb
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_NestedMap__241, isTrue$91ea4ebb04f439fb);

jboolean
_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb(_jc_env *const env, _jc_polyglot_util_NestedMap__241$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_polyglot_util_NestedMap__241$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_object *r2;
	struct _jc_polyglot_util_NestedMap$object *r3;
	struct _jc_java_util_HashMap$object *r6;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(160);				// 0
	r2 = _JC_CAST(env, &_jc_java_util_Map__24Entry$type, r1);
	_JC_LINE_NUMBER(161);				// 1
	r3 = _JC_REF_FIELD(env, r0, polyglot_util_NestedMap__241, this__240);
	_JC_ACTIVE_USE(env, polyglot_util_NestedMap);
	r6 = _JC_REF_FIELD(env, r3, polyglot_util_NestedMap, myMap);
	r1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x36389701bfdf0ba9), _jc_object *);
	z0 = _JC_INVOKE_VIRTUAL(env, java_util_HashMap, containsKey$5db565349ffc17b2, r6, r1);
	if (z0 != 0)
		goto label0;
	z0 = 1;
	goto label1;

label0:
	z0 = 0;

label1:
	return z0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_util_NestedMap__241$methods[] = {
	&_jc_polyglot_util_NestedMap__241$method_info$_init$e86507e3abc60b21,
	&_jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_polyglot_util_NestedMap__241$interfaces[] = {
	&_jc_polyglot_util_Predicate$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_polyglot_util_NestedMap__241$imethod_hash_bucket_123[] = {
	&_jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_polyglot_util_NestedMap__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[123]=	_jc_polyglot_util_NestedMap__241$imethod_hash_bucket_123
};

// Interface "quick" lookup hash table
static const void *_jc_polyglot_util_NestedMap__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[123]=	&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_37[] = {
	&_jc_polyglot_util_NestedMap__241$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_123[] = {
	&_jc_polyglot_util_Predicate$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_util_NestedMap__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[37]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_37,
	[113]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_113,
	[123]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_123
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_util_NestedMap__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
	{ "java/util/Map$Entry",	_JC_JLONG(0x3222d3e1e6ee5a41) },
	{ "polyglot/util/NestedMap",	_JC_JLONG(0x8c5d73b7858cb7f9) },
	{ "polyglot/util/Predicate",	_JC_JLONG(0xdd63687c349023fb) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_util_NestedMap__241$vtype _jc_polyglot_util_NestedMap__241$type = {
    .type= {
	.name=			"polyglot/util/NestedMap$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_polyglot_util_NestedMap__241$interfaces) / sizeof(*_jc_polyglot_util_NestedMap__241$interfaces),
	.interfaces=		_jc_polyglot_util_NestedMap__241$interfaces,
	.imethod_hash_table=	_jc_polyglot_util_NestedMap__241$imethod_hash_table,
	.imethod_quick_table=	_jc_polyglot_util_NestedMap__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x783f7398f16c5125),
		.source_file=		"NestedMap.java",
		.instance_size=		sizeof(_jc_polyglot_util_NestedMap__241$refs) + sizeof(_jc_polyglot_util_NestedMap__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_polyglot_util_NestedMap__241$fields) / sizeof(*_jc_polyglot_util_NestedMap__241$fields),
		.fields=		_jc_polyglot_util_NestedMap__241$fields,
		.num_methods=		sizeof(_jc_polyglot_util_NestedMap__241$methods) / sizeof(*_jc_polyglot_util_NestedMap__241$methods),
		.methods=		_jc_polyglot_util_NestedMap__241$methods,
		.instanceof_hash_table=	_jc_polyglot_util_NestedMap__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_util_NestedMap__241$class_depends) / sizeof(*_jc_polyglot_util_NestedMap__241$class_depends),
		.class_depends=		_jc_polyglot_util_NestedMap__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_NestedMap__241= {
	    .isTrue$91ea4ebb04f439fb=
		&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/util/NestedMap__241.c <==
// class polyglot.util.NestedMap$1

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 3222d3e1e6ee5a41 java_util_Map__24Entry
// @dep_class 8c5d73b7858cb7f9 polyglot_util_NestedMap
// @dep_class 783f7398f16c5125 polyglot_util_NestedMap__241
// @dep_class dd63687c349023fb polyglot_util_Predicate

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_HashMap
// @dep_header java_util_Map__24Entry
// @dep_header polyglot_util_NestedMap
// @dep_header polyglot_util_NestedMap__241
// @dep_header polyglot_util_Predicate

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/HashMap.h"
#include "java/util/Map__24Entry.h"
#include "polyglot/util/NestedMap.h"
#include "polyglot/util/NestedMap__241.h"
#include "polyglot/util/Predicate.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final polyglot.util.NestedMap this$0
static _jc_field _jc_polyglot_util_NestedMap__241$field_info$this__240 = {
	.name=		"this$0",
	.signature=	"Lpolyglot/util/NestedMap;",
	.class=		&_jc_polyglot_util_NestedMap__241$type,
	.type=		&_jc_polyglot_util_NestedMap$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_NestedMap__241$object, refs[-1].polyglot_util_NestedMap__241.this__240),
};

// Fields
static _jc_field *const _jc_polyglot_util_NestedMap__241$fields[] = {
	&_jc_polyglot_util_NestedMap__241$field_info$this__240
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(polyglot.util.NestedMap)
//

static _jc_linenum _jc_polyglot_util_NestedMap__241$linenum_table$_init$e86507e3abc60b21[];

static const unsigned char _jc_polyglot_util_NestedMap__241$param_ptypes$_init$e86507e3abc60b21[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_util_NestedMap__241$param_types$_init$e86507e3abc60b21[] = {
	&_jc_polyglot_util_NestedMap$type
};

_jc_method _jc_polyglot_util_NestedMap__241$method_info$_init$e86507e3abc60b21 = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/NestedMap;)V",
	.class=			&_jc_polyglot_util_NestedMap__241$type,
	.param_types=		&_jc_polyglot_util_NestedMap__241$param_types$_init$e86507e3abc60b21,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_util_NestedMap__241$param_ptypes$_init$e86507e3abc60b21,
	.signature_hash=	_JC_JLONG(0xe86507e3abc60b21),
	.access_flags=		0,
	.function=		&_jc_polyglot_util_NestedMap__241$method$_init$e86507e3abc60b21,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_NestedMap__241$linenum_table$_init$e86507e3abc60b21
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_NestedMap__241, _init$e86507e3abc60b21);

void _JC_JCNI_ATTR
_jc_polyglot_util_NestedMap__241$method$_init$e86507e3abc60b21(_jc_env *const env, _jc_polyglot_util_NestedMap__241$object *this, _jc_polyglot_util_NestedMap$object *param0)
{
	struct _jc_polyglot_util_NestedMap__241$object *r0;
	struct _jc_polyglot_util_NestedMap$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(159);				// 0
	_JC_REF_FIELD(env, r0, polyglot_util_NestedMap__241, this__240) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean isTrue(java.lang.Object)
//

static _jc_linenum _jc_polyglot_util_NestedMap__241$linenum_table$isTrue$91ea4ebb04f439fb[];

static const unsigned char _jc_polyglot_util_NestedMap__241$param_ptypes$isTrue$91ea4ebb04f439fb[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_polyglot_util_NestedMap__241$param_types$isTrue$91ea4ebb04f439fb[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb = {
	.name=			"isTrue",
	.signature=		"(Ljava/lang/Object;)Z",
	.class=			&_jc_polyglot_util_NestedMap__241$type,
	.param_types=		&_jc_polyglot_util_NestedMap__241$param_types$isTrue$91ea4ebb04f439fb,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_polyglot_util_NestedMap__241$param_ptypes$isTrue$91ea4ebb04f439fb,
	.signature_hash=	_JC_JLONG(0x91ea4ebb04f439fb),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_NestedMap__241$vtable, polyglot_util_NestedMap__241.isTrue$91ea4ebb04f439fb) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_polyglot_util_NestedMap__241$linenum_table$isTrue$91ea4ebb04f439fb
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_NestedMap__241, isTrue$91ea4ebb04f439fb);

jboolean _JC_JCNI_ATTR
_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb(_jc_env *const env, _jc_polyglot_util_NestedMap__241$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_polyglot_util_NestedMap__241$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_object *r2;
	struct _jc_polyglot_util_NestedMap$object *r3;
	struct _jc_java_util_HashMap$object *r6;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(160);				// 0
	r2 = _JC_CAST(env, &_jc_java_util_Map__24Entry$type, r1);
	_JC_LINE_NUMBER(161);				// 1
	r3 = _JC_REF_FIELD(env, r0, polyglot_util_NestedMap__241, this__240);
	_JC_ACTIVE_USE(env, polyglot_util_NestedMap);
	r6 = _JC_REF_FIELD(env, r3, polyglot_util_NestedMap, myMap);
	r1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x36389701bfdf0ba9), _jc_object *, (_jc_env *, struct _jc_object *));
	z0 = _JC_INVOKE_VIRTUAL(env, java_util_HashMap, containsKey$5db565349ffc17b2, r6, r1);
	if (z0 != 0)
		goto label0;
	z0 = 1;
	goto label1;

label0:
	z0 = 0;

label1:
	return z0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_util_NestedMap__241$methods[] = {
	&_jc_polyglot_util_NestedMap__241$method_info$_init$e86507e3abc60b21,
	&_jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_polyglot_util_NestedMap__241$interfaces[] = {
	&_jc_polyglot_util_Predicate$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_polyglot_util_NestedMap__241$imethod_hash_bucket_123[] = {
	&_jc_polyglot_util_NestedMap__241$method_info$isTrue$91ea4ebb04f439fb,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_polyglot_util_NestedMap__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[123]=	_jc_polyglot_util_NestedMap__241$imethod_hash_bucket_123
};

// Interface "quick" lookup hash table
static const void *_jc_polyglot_util_NestedMap__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[123]=	&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_37[] = {
	&_jc_polyglot_util_NestedMap__241$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_123[] = {
	&_jc_polyglot_util_Predicate$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_util_NestedMap__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[37]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_37,
	[101]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_101,
	[123]=	_jc_polyglot_util_NestedMap__241$instanceof_hash_bucket_123
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_util_NestedMap__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
	{ "java/util/Map$Entry",	_JC_JLONG(0x3222d3e1e6ee5a41) },
	{ "polyglot/util/NestedMap",	_JC_JLONG(0x8c5d73b7858cb7f9) },
	{ "polyglot/util/Predicate",	_JC_JLONG(0xdd63687c349023fb) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_util_NestedMap__241$vtype _jc_polyglot_util_NestedMap__241$type = {
    .type= {
	.name=			"polyglot/util/NestedMap$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_polyglot_util_NestedMap__241$interfaces) / sizeof(*_jc_polyglot_util_NestedMap__241$interfaces),
	.interfaces=		_jc_polyglot_util_NestedMap__241$interfaces,
	.imethod_hash_table=	_jc_polyglot_util_NestedMap__241$imethod_hash_table,
	.imethod_quick_table=	_jc_polyglot_util_NestedMap__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x783f7398f16c5125),
		.source_file=		"NestedMap.java",
		.instance_size=		sizeof(_jc_polyglot_util_NestedMap__241$refs) + sizeof(_jc_polyglot_util_NestedMap__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_polyglot_util_NestedMap__241$fields) / sizeof(*_jc_polyglot_util_NestedMap__241$fields),
		.fields=		_jc_polyglot_util_NestedMap__241$fields,
		.num_methods=		sizeof(_jc_polyglot_util_NestedMap__241$methods) / sizeof(*_jc_polyglot_util_NestedMap__241$methods),
		.methods=		_jc_polyglot_util_NestedMap__241$methods,
		.instanceof_hash_table=	_jc_polyglot_util_NestedMap__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_util_NestedMap__241$class_depends) / sizeof(*_jc_polyglot_util_NestedMap__241$class_depends),
		.class_depends=		_jc_polyglot_util_NestedMap__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_NestedMap__241= {
	    .isTrue$91ea4ebb04f439fb=
		&_jc_polyglot_util_NestedMap__241$method$isTrue$91ea4ebb04f439fb,
	},
    }
};
